Documentation
¶
Index ¶
Constants ¶
const ( DefaultLifetime = 5 * time.Minute DefaultHostname = "localhost" DefaultPort = 5672 DefaultUsername = "guest" DefaultPassword = "guest" DefaultLogger = log.Discard )
The default client configuration
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
Lifetime time.Duration // The length of time after which a message is automatically requeued
Address *address.Address // The address of the RabbitMQ server
Username string // The username for RabbitMQ
Password string // The password for RabbitMQ
Logger log.Interface // The logger
}
Config describes the configuration options we allow a user to set on a RabbitMQ driver.
func DefaultConfig ¶
func DefaultConfig() *Config
DefaultConfig returns a new client configuration initialised with the default values.
func SetDefaultConfig ¶
SetDefaultConfig sets the default configuration to c and returns the old default configuration. This change will be reflected in future calls to DefaultConfig.
Click to show internal directories.
Click to hide internal directories.